
/* m1.c -- uses the mgraf code. */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <errno.h>
#include <unistd.h>
#include <stdint.h>

/* For GPIO */
#include <sys/mman.h>
#include "kgpio.h"

/* For SPI */
#include <sys/ioctl.h>
#include <linux/types.h>
#include <linux/spi/spidev.h>

#include "mgraf.h"

/* Each byte maps to a cell 8 pixels tall so there are 6 rows
	with 8 cells in each, for 48 pixels vertical.

	Top pixel is the LSB. With normal video, bits 1 show pixels and bits
	0 do not. 

	So, let's see -- for meaningful graphics we will have to
	maintain a readable copy of the image in memory, and when drawing, 
	update those bytes that are affected.

	There is a total of 504 bytes, so the memory needed is modest.
	In addition we will want to keep some flags indicating need for
	update. (unless the gotoxy+write is more than just write 504,
	but that can be determined in each case: if too many bytes need
	updating scattered around, then just blast out the entire lot
	in one go.	504 bytes to write vs 3*updcount: 504/3 = 168 ... hmm).
*/

/* Draw/undraw a single pixel. */
/* Draw a v.line at x from y1 to y2. */
/* Draw a h.line from x1 to x2 at y. */
/* Draw strings of text at X,Y. */

/* Plot some data in a rectangular plot with X and Y */

char *aimt5x5(int cx, int row);

void BlitChar(struct dispinfo *PDI, uint8_t xtl, uint8_t ytl, int thechar)
{
	int j;
	for(j = 0; j<5; j++)
	{
		BlitLine(PDI, xtl, xtl+4, ytl+j, (uint8_t *) aimt5x5(thechar, j) );
	}
}


/* Draw some characters, and a long narrow rectangle */

int main()
{
	struct dispinfo DI;
	int ds, j;
	char infobuf[128];
	uint8_t xrcat, yrcat;

	ds = displayinit(&DI, infobuf, 128);
	if(ds < 0)
	{
		fprintf(stderr, "%s\n", infobuf);
		return(0);
	}
	
	xrcat = 0;
	yrcat = 0;

	for(j = 33; j<96; j++)
	{
		BlitChar(&DI, xrcat, yrcat, j);
		xrcat += 6;
		if(xrcat >= 83)
		{
			xrcat = 0;
			yrcat += 6;
		}
	}

	Hline(&DI, 10, 60, 41, 0);
	Hline(&DI, 10, 60, 46, 0);
	Vline(&DI, 10, 41, 46, 0);
	Vline(&DI, 60, 41, 46, 0);

	refreshflagged(&DI);

	displayexit(&DI);
	return(0);
}



