
#ifndef MGRAFHINCLUDED
#define MGRAFHINCLUDED


/* Display connections:
	1: Vcc 3.3V
	2: GND
	3: SCE(L) - CS0(L) P1-24
	4: RST(L) - GPIO24 P1-18
	5: D/C -    GPIO25 P1-22
	6: MOSI   - MOSI   P1-19
	7: SCLK   - SCLK   P1-23
*/

#define MD_RESET 24
#define MD_D_C 25

/* 
	GPsetcap(volatile uint32_t *gpio, MD_RESET, GPIO_OUTPUT); 
	GPsetcap(volatile uint32_t *gpio, MD_D_C, GPIO_OUTPUT);

	Reset the device:
	GPset(volatile uint32_t *gpio, MD_RESET);
	GPclear(volatile uint32_t *gpio, MD_RESET);
	GPset(volatile uint32_t *gpio, MD_RESET);

	Select to write Commands:
	GPclear(volatile uint32_t *gpio, MD_D_C);

	Select to write Data:
	GPset(volatile uint32_t *gpio, MD_D_C);
*/

/* SPI:  Open, set mode, bits per word, speed.
	Display is write-only so we can use write() to push data to it.
	More advanced is the ioctl(SPI_IOC_MESSAGE(N)) for N messages, 
	each containing a transmission and a reception part.
*/

struct dispinfo
{
	volatile uint32_t *gpio;
	int fd;
};

/* Size of LCD is 84 (chars? bytes?) wide and 48 tall */ 
#define LCD_X 84
#define LCD_Y 48

void displayexit(struct dispinfo *PDI);

int displayinit(struct dispinfo *PDI, char *infobuf, size_t ibmax);


/* Start writing at address x,y indicated. */
void gotoxy(struct dispinfo *PDI, uint8_t x, uint8_t y);

/* Each byte maps to a cell 8 pixels tall so there are 6 rows
	with 8 cells in each, for 48 pixels vertical.

	Top pixel is the LSB. With normal video, bits 1 show pixels and bits
	0 do not. 

	So, let's see -- for meaningful graphics we will have to
	maintain a readable copy of the image in memory, and when drawing, 
	update those bytes that are affected.

	There is a total of 504 bytes, so the memory needed is modest.
	In addition we will want to keep some flags indicating need for
	update. (unless the gotoxy+write is more than just write 504,
	but that can be determined in each case: if too many bytes need
	updating scattered around, then just blast out the entire lot
	in one go.	504 bytes to write vs 3*updcount: 504/3 = 168 ... hmm).
*/

/* Draw/undraw a single pixel. */
/* Draw a v.line at x from y1 to y2. */
/* Draw a h.line from x1 to x2 at y. */
/* Draw strings of text at X,Y. */

/* Plot some data in a rectangular plot with X and Y */
/* What was the size of the font from CANIS and SYM7? */


/* Write all zeros. */
void clear(struct dispinfo *PDI);


/* Write all ones. */
void unclear(struct dispinfo *PDI);

#if(0)

int main()
{
	struct dispinfo DI;
	int ds, j;
	char xpa[3];
	char infobuf[128];

	ds = displayinit(&DI, infobuf, 128);
	if(ds < 0)
	{
		fprintf(stderr, "%s\n", infobuf);
		return(0);
	}
	fprintf(stderr, "About to clear...\n" );

	clear(&DI);
	sleep(1);

	gotoxy(&DI, 0, 0);
	GPset(DI.gpio, MD_D_C);     /* Write Data. */

	// xpa[0] = 0x55;
	// xpa[1] = 0xaa;

	for(j = 0; j<80; j++)
	{
		// write(DI.fd, xpa, 2);
		xpa[0] = j;
		write(DI.fd, xpa, 1);
	}

	// fprintf(stderr, "About to set...\n" );
	// unclear(&DI);
	// sleep(1);

	// fprintf(stderr, "About to clear again ...\n" );
	// clear(&DI);

	displayexit(&DI);
	return(0);
}


	// GPset(PDI->gpio, MD_D_C);     /* Write Data. */
	// GPclear(PDI->gpio, MD_D_C);     /* Write Command. */
	// extern uint8_t TXT5x8[][5] ;

#endif

#endif
