
#ifndef MGRAFHINCLUDED
#define MGRAFHINCLUDED


/* Display connections:
	1: Vcc 3.3V
	2: GND
	3: SCE(L) - CS0(L) P1-24
	4: RST(L) - GPIO24 P1-18
	5: D/C -    GPIO25 P1-22
	6: MOSI   - MOSI   P1-19
	7: SCLK   - SCLK   P1-23
*/

#define MD_RESET 24
#define MD_D_C 25

/* 
	GPsetcap(volatile uint32_t *gpio, MD_RESET, GPIO_OUTPUT); 
	GPsetcap(volatile uint32_t *gpio, MD_D_C, GPIO_OUTPUT);

	Reset the device:
	GPset(volatile uint32_t *gpio, MD_RESET);
	GPclear(volatile uint32_t *gpio, MD_RESET);
	GPset(volatile uint32_t *gpio, MD_RESET);

	Select to write Commands:
	GPclear(volatile uint32_t *gpio, MD_D_C);

	Select to write Data:
	GPset(volatile uint32_t *gpio, MD_D_C);
*/

/* SPI:  Open, set mode, bits per word, speed.
	Display is write-only so we can use write() to push data to it.
	More advanced is the ioctl(SPI_IOC_MESSAGE(N)) for N messages, 
	each containing a transmission and a reception part.
*/

struct dispinfo
{
	volatile uint32_t *gpio;
	int fd;
	uint8_t space[504];
	uint8_t flags[504];
};

/* Size of LCD is 84 (chars? bytes?) wide and 48 tall */ 
#define LCD_X 84
#define LCD_Y 48

void displayexit(struct dispinfo *PDI);

int displayinit(struct dispinfo *PDI, char *infobuf, size_t ibmax);

/* Update the entire display from the space array. Writes
	all 504 bytes out. */

void refreshfull(struct dispinfo *PDI);


/* No idea if this is faster? well, there will be 
	less IO for smaller changes. */
void refreshflagged(struct dispinfo *PDI);

/* Force raw X and Y values to stay on the screen */
void hardlimitx(uint8_t *px);

void hardlimity(uint8_t *py);

/* Draw/erase a vertical line at x from y1 to y2. 
	X and Y are pixel addresses (0-83, 0-47). */

void Vline(struct dispinfo *PDI, uint8_t x, uint8_t y1, uint8_t y2, int erases);

/* Draw/erase a horizontal line from x1 to x2 at y. */
void Hline(struct dispinfo *PDI, uint8_t x1, uint8_t x2, uint8_t y, int erases);

/* Draw/erase pixels along a horizontal line from x1 to x2 at y,
	where the pattern indicates which are to be on or off. 
	The array must be big enough to cover x1 to x2 inclusive.
	first byte MSB matches x1, first byte second SB matches x1+1 and so
	on up to and including x2. */

void BlitLine(struct dispinfo *PDI, 
	uint8_t x1, uint8_t x2, uint8_t y, uint8_t *pattern); 


/* Each byte maps to a cell 8 pixels tall so there are 6 rows
	with 8 cells in each, for 48 pixels vertical.

	Top pixel is the LSB. With normal video, bits 1 show pixels and bits
	0 do not. 

	So, let's see -- for meaningful graphics we will have to
	maintain a readable copy of the image in memory, and when drawing, 
	update those bytes that are affected.

	There is a total of 504 bytes, so the memory needed is modest.
	In addition we will want to keep some flags indicating need for
	update. (unless the gotoxy+write is more than just write 504,
	but that can be determined in each case: if too many bytes need
	updating scattered around, then just blast out the entire lot
	in one go.	504 bytes to write vs 3*updcount: 504/3 = 168 ... hmm).
*/

/* What was the size of the font from CANIS and SYM7? */

/* Write all zeros. */
void clear(struct dispinfo *PDI);

/* Put out a character from the 5x5 pattern set onto the screen */
void BlitChar(struct dispinfo *PDI, uint8_t xtl, uint8_t ytl, int thechar);

/* Put out an entire zero-terminated string beginning at 
	specified location and going right and down. */ 

void BlitString(struct dispinfo *PDI, 
	uint8_t xtl, uint8_t ytl, char *thestring);

/* Draw/undraw a single pixel. */
void Pixel(struct dispinfo *PDI, uint8_t x, uint8_t y, int undraw);

/* Plot some data in a rectangular plot with X and Y */

#endif


