
/* mpax.c -- panel example  */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <stdint.h>
#include <unistd.h>
#include <signal.h>

#include "mgraf.h"
#include "panel.h"
#include "gammapb_u.h"
#include "gpbrx.h"

/* Globals so we can see them in the signal-handlers as well. */ 
struct dispinfo G_DI;
struct panel *PAshow; 


static void on_deasil(int sig, siginfo_t *siginfo, void *c)
{
	// printf("Noted deasil movement\n");
	// usleep(50);
	panelselmove(PAshow, 1);
	showpanel(PAshow, &G_DI); 
	return;
}

static void on_widdershins(int sig, siginfo_t *siginfo, void *c)
{
	// printf("Noted widdershins movement\n");
	// usleep(50);
	panelselmove(PAshow, -1);
	showpanel(PAshow, &G_DI); 
	return;
}

int G_pushed; 

static void on_push(int sig, siginfo_t *siginfo, void *c)
{
	printf("Got a push\n");
	usleep(100);
	G_pushed = 1; 
	return;
}


int G_rflag;

void sigintcatcher(int sig, siginfo_t *siginfo, void *c)
{
	printf("Caught SIGINT, will exit.\n" ); 
	G_rflag = 1;
	return;
}

int main(int argc, char **argv)
{
	struct dispinfo *DI;
	struct panel *PA; 
	int ds;
	char infobuf[128];
	struct sigaction sact;

	DI = &G_DI;
	ds = displayinit(DI, infobuf, 128);
	if(ds < 0)
	{
		fprintf(stderr, "%s\n", infobuf);
		return(0);
	}

	memset(&sact, 0, sizeof(struct sigaction)); 
	sact.sa_sigaction = sigintcatcher;
	sact.sa_flags = SA_SIGINFO | SA_RESTART; 
	sigaction(SIGINT, &sact, 0);

	memset(&sact, 0, sizeof(struct sigaction)); 
	sact.sa_sigaction = on_push;
	sact.sa_flags = SA_SIGINFO | SA_RESTART; 
	sigaction(SIG_PB, &sact, 0);

	memset(&sact, 0, sizeof(struct sigaction)); 
	sact.sa_sigaction = on_deasil;
	sact.sa_flags = SA_SIGINFO | SA_RESTART; 
	sigaction(SIG_DEASIL, &sact, 0);

	memset(&sact, 0, sizeof(struct sigaction)); 
	sact.sa_sigaction = on_widdershins;
	sact.sa_flags = SA_SIGINFO | SA_RESTART; 
	sigaction(SIG_WIDDERSHINS, &sact, 0);

	G_rflag = 0;

	GPBU_TurnOn();

	/* Create the root panel. */

	PA = makepanelV(4, "Hei", "Hallo", "Tut", "Jadda", NULL); 
	PAshow = PA; 
	showpanel(PA, &G_DI); 

	for(;;)
	{
		if(G_pushed)
		{
			printf("Selected item %d\n", panelselread(PA) );
			G_pushed = 0; 
		}


		/* In the loop we can look at the signals having been sent. */

		if(G_rflag) break;
	}

	GPBU_Send("stop");
	GPBU_TurnOff();
	displayexit(DI);
	removepanel(&PA); 
	return(0);
}


#if(0)
int main(int argc, char **argv)
{
	int ds, j;
	char infobuf[128];
	char txt[90];

	ds = displayinit(&DI, infobuf, 128);
	if(ds < 0)
	{
		fprintf(stderr, "%s\n", infobuf);
		return(0);
	}

	PA = makepanelV(4, "Hei", "Hallo", "Tut", "Jadda", NULL); 

	showpanel(PA, &DI); 

	// refreshflagged(&DI);


	fputs("Hit Return to stop ... \n", stdout); 
	fgets(txt, 90, stdin); 

	removepanel(&PA); 
	displayexit(&DI);
	return(0);
}
#endif



