
#include <stdio.h>
#include <stdarg.h>
#include <stdint.h>
#include <utilib.h>
#include "mgraf.h"
#include "panel.h"

/* Varargs definition */
struct panel *makepanelV(int icount, ...)
{
	va_list ap;
	int argn;
	char *Args[1000];

	va_start(ap, icount); 

	argn = 0; 
	for(;;)
	{
		Args[argn] = va_arg(ap, char *);
		if(Args[argn] == NULL) break;
		argn++;
	}
	va_end(ap);
	return makepanel(icount, Args); 
}


/* Make the panel with the items in it. */ 
struct panel *makepanel(int icount, char **items)
{
	struct panel *P;
	int j;

	P = (struct panel *) Alloc1D(sizeof(struct panel)); 

	for(j = 0; j<8; j++)
	{
		P->itemstrings[j] = Alloc1D(100);
	}

	P->itemcount = icount;		/* 1 for info-panel, 2-8 for a menu-panel. */

	for(j = 0; j<P->itemcount; j++)
	{
		snprintf(P->itemstrings[j], 100, "%s", items[j]);
	}
	P->iselnow = -1;	/* Indicates the present selection, 
							-1 for no present selection. */

	return(P);
}

void removepanel(struct panel **PP)
{
	int j;
	for(j = 0; j<8; j++)
	{
		Free1D( (*PP)->itemstrings[j]); 
	}
	Free1D(*PP); 
	*PP = NULL;
	return;
}


/* Display the panel, using the display-info. */
int showpanel(struct panel *P, struct dispinfo *DI)
{
	int j; 
	char histring[80];

	for(j = 0; j<P->itemcount; j++)
	{
		if(j == P->iselnow)
		{
			snprintf(histring, 80, ">%s", P->itemstrings[j]); 
		}
		else
		{
			snprintf(histring, 80, " %s", P->itemstrings[j]); 
		}
		BlitString(DI, 0, j*6, histring); 
	}
	refreshflagged(DI); 
	return(j);
}


/* Return the selection made */
int panelselread(struct panel *P) 
{
	return P->iselnow; 
}

/* Move selection in the panel up or down. */
int panelselmove(struct panel *P, int direction) 
{
	int nsel;
	nsel = P->iselnow + ( direction > 0 ? 1 : -1); 
	if(nsel < 0) nsel = 0;
	if(nsel >= P->itemcount) nsel = P->itemcount-1; 
	P->iselnow = nsel;	
	return(nsel);
}






/* Panel -- 8 lines of text (max).
	Models:
		menupanel:
			2-8 menu selections
		infopanel:
			panel with info (text or graphics) and
				one defined selection such as "back" or "exit"
*/

#ifndef PANELHINCLUDED
#define PANELHINCLUDED 1

struct panel
{
	int itemcount;		/* 1 for info-panel, 2-8 for a menu-panel. */
	char *itemstrings[8];
	int iselnow;			/* Indicates the present selection */
};




#endif


