
/* m1.c -- uses the mgraf code. */

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <fcntl.h>
#include <errno.h>
#include <unistd.h>
#include <stdint.h>

/* For GPIO */
#include <sys/mman.h>
#include "kgpio.h"

/* For SPI */
#include <sys/ioctl.h>
#include <linux/types.h>
#include <linux/spi/spidev.h>

#include "mgraf.h"

/* Each byte maps to a cell 8 pixels tall so there are 6 rows
	with 8 cells in each, for 48 pixels vertical.

	Top pixel is the LSB. With normal video, bits 1 show pixels and bits
	0 do not. 

	So, let's see -- for meaningful graphics we will have to
	maintain a readable copy of the image in memory, and when drawing, 
	update those bytes that are affected.

	There is a total of 504 bytes, so the memory needed is modest.
	In addition we will want to keep some flags indicating need for
	update. (unless the gotoxy+write is more than just write 504,
	but that can be determined in each case: if too many bytes need
	updating scattered around, then just blast out the entire lot
	in one go.	504 bytes to write vs 3*updcount: 504/3 = 168 ... hmm).
*/

/* Draw/undraw a single pixel. */
/* Draw a v.line at x from y1 to y2. */
/* Draw a h.line from x1 to x2 at y. */
/* Draw strings of text at X,Y. */

/* Plot some data in a rectangular plot with X and Y */
/* What was the size of the font from CANIS and SYM7? 7x9, 8x8... hmm. */

#if(0)
char *aimt5x5(int cx, int row);

void BlitChar(struct dispinfo *PDI, uint8_t xtl, uint8_t ytl, int thechar)
{
	int j;
	for(j = 0; j<5; j++)
	{
		BlitLine(PDI, xtl, xtl+4, ytl+j, (uint8_t *) aimt5x5(thechar, j) );
	}
}
#endif


int main()
{
	struct dispinfo DI;
	int ds, j;
	// char xpa[3];
	char infobuf[128];
	uint8_t xrcat, yrcat;

	ds = displayinit(&DI, infobuf, 128);
	if(ds < 0)
	{
		fprintf(stderr, "%s\n", infobuf);
		return(0);
	}
	
	// Hline(&DI, 10, 40, 20, 0);
	// Vline(&DI, 10, 20, 30, 0);
	// Vline(&DI, 40, 20, 30, 0);
	// Hline(&DI, 10, 40, 30, 0);

	// for(j = 0; j<20; j++)
	// {
		// Vline(&DI, 3+j, 4, 4+j, 0);
	// }

	// BlitChar(&DI, 50, 10, 'H', 0);
	// BlitChar(&DI, 56, 10, 'E', 0);
	// BlitChar(&DI, 62, 10, 'L', 0);
	// BlitChar(&DI, 68, 10, 'L', 0);
	// BlitChar(&DI, 74, 10, 'O', 0);

	xrcat = 0;
	yrcat = 0;

	for(j = 33; j<127; j++)
	{
		BlitChar(&DI, xrcat, yrcat, j);
		xrcat += 6;
		if(xrcat >= 83)
		{
			xrcat = 0;
			yrcat += 6;
		}
	}

#if(0)

	BlitLine(&DI, 45, 55, 10, (uint8_t *) "\x55\x55");  
	BlitLine(&DI, 45, 55, 11, (uint8_t *) "\xaa\xaa");
	BlitLine(&DI, 45, 55, 12, (uint8_t *) "\x55\x55");
	BlitLine(&DI, 45, 55, 13, (uint8_t *) "\xaa\xaa");
	BlitLine(&DI, 45, 55, 14, (uint8_t *) "\x55\x55");
	BlitLine(&DI, 45, 55, 15, (uint8_t *) "\xaa\xaa");
	BlitLine(&DI, 45, 55, 16, (uint8_t *) "\x55\x55");
	BlitLine(&DI, 45, 55, 17, (uint8_t *) "\xaa\xaa");

	/* Something look like an A, 5 by 5 or so. */
	BlitLine(&DI, 60, 64, 10, (uint8_t *) "\x70");		// .111....
	BlitLine(&DI, 60, 64, 11, (uint8_t *) "\x88");		// 1...1...
	BlitLine(&DI, 60, 64, 12, (uint8_t *) "\xf8");		// 11111...
	BlitLine(&DI, 60, 64, 13, (uint8_t *) "\x88");		// 1...1...
	BlitLine(&DI, 60, 64, 14, (uint8_t *) "\x88");		// 1...1...

	/* Then a B */
	BlitLine(&DI, 66, 70, 10, (uint8_t *) "\xf0");		// 1111....
	BlitLine(&DI, 66, 70, 11, (uint8_t *) "\x88");		// 1...1...
	BlitLine(&DI, 66, 70, 12, (uint8_t *) "\xf0");		// 1111....
	BlitLine(&DI, 66, 70, 13, (uint8_t *) "\x88");		// 1...1...
	BlitLine(&DI, 66, 70, 14, (uint8_t *) "\xf0");		// 1111....
	
	BlitLine(&DI, 72, 76, 10, (uint8_t *) "\x78");		// .1111...
	BlitLine(&DI, 72, 76, 11, (uint8_t *) "\x80");		// 1.......
	BlitLine(&DI, 72, 76, 12, (uint8_t *) "\x80");		// 1.......
	BlitLine(&DI, 72, 76, 13, (uint8_t *) "\x80");		// 1......
	BlitLine(&DI, 72, 76, 14, (uint8_t *) "\x78");		// .1111...
#endif

	refreshflagged(&DI);

	// refreshfull(&DI);

	// fprintf(stderr, "About to clear...\n" );

	// clear(&DI);
	// sleep(1);

	// gotoxy(&DI, 0, 0);
	// GPset(DI.gpio, MD_D_C);     /* Write Data. */

	// xpa[0] = 0x55;
	// xpa[1] = 0xaa;

	// for(j = 0; j<80; j++)
	// {
		// write(DI.fd, xpa, 2);
		// xpa[0] = j;
		// write(DI.fd, xpa, 1);
	// }

	// fprintf(stderr, "About to clear again ...\n" );
	// clear(&DI);

	displayexit(&DI);
	return(0);
}


	// GPset(PDI->gpio, MD_D_C);     /* Write Data. */
	// GPclear(PDI->gpio, MD_D_C);     /* Write Command. */
	// extern uint8_t TXT5x8[][5] ;



